@@ -1234,22 +1234,29 @@ class PODsegment(Segment):
         msg = Segment.__str__(self)
         for j in range(len(self.rspod)):
 
-            msg += '\n    '
-            lines = ['Progression change {0}:',
-                     '    Resolution index start:  {1}',
-                     '    Component index start:  {2}',
-                     '    Layer index end:  {3}',
-                     '    Resolution index end:  {4}',
-                     '    Component index end:  {5}',
-                     '    Progression order:  {6}']
-            submsg = '\n    '.join(lines)
+            submsg = (
+                '\n'
+                '    Progression change {0}:\n'
+                '        Resolution index start:  {1}\n'
+                '        Component index start:  {2}\n'
+                '        Layer index end:  {3}\n'
+                '        Resolution index end:  {4}\n'
+                '        Component index end:  {5}\n'
+                '        Progression order:  {6}'
+            )
+
+            try:
+                progorder = _PROGRESSION_ORDER_DISPLAY[self.ppod[j]]
+            except KeyError:
+                progorder = 'invalid value: {0}'.format(self.ppod[j])
+
             msg += submsg.format(j,
                                  self.rspod[j],
                                  self.cspod[j],
                                  self.lyepod[j],
                                  self.repod[j],
                                  self.cdpod[j],
-                                 _PROGRESSION_ORDER_DISPLAY[self.ppod[j]])
+                                 progorder)
 
         return msg
 
